#!/bin/bash
#
# utserv - script to quickly launch a dedicated
#          Unreal Tournament server for Linux
#
# originally by Joseph David Blough <jblough@umich.edu>
# modifications by Andy Piper <andyp@unrealtournament.org>
# More modifications by Michael West <mwes4@ironbark.bendigo.latrobe.edu.au>
#
# Version 2 - 26/09/2000 - mutators now selectable
# Version 3 - 31/10/2000 - launch custom ini files and temporary files 
#                          created in $UTSERVTMP/
#
# requires: bash, dialog, sed, perl, Unreal Tournament
#
# should be copied to and run from the System/
# directory of the Unreal Tournament installation
# along with the generate_mutator_list.pl script
# 

# setup a global containing a location for the temporary files
# we'll use /var/tmp to match the Linux FHS, but it can be changed...
UTSERVTMP=/var/tmp

# function to remove temporary files created by the script
cleanup() {
	rm -f $UTSERVTMP/.tournament_type $UTSERVTMP/.map_menu_options $UTSERVTMP/.temp_file_output
	rm -f $UTSERVTMP/.mutators_available $UTSERVTMP/.mutators_selected $UTSERVTMP/.mutators_selected_string
	rm -f $UTSERVTMP/.init_string
}

# function to exit the script if the user cancels
die() {
	echo "UT Server cancelled"
	cleanup
	exit 1
}

dm='Deathmatch'
ctf='Capture The Flag'
dom='Domination'
as='Assault'

dialog --menu "Tournament Type" 20 50 10 \
	"$dm" "" "$ctf" "" "$dom" "" "$as" "" 2> $UTSERVTMP/.tournament_type

if [ $? != 0 ]; then
	die
fi

read tournament_type < $UTSERVTMP/.tournament_type
command_to_run="--menu Maps 20 50 10 \\"
echo $command_to_run > $UTSERVTMP/.map_menu_options

# default to deathmatch

case $tournament_type in
 $dm)
      map_prefix=DM
	  ;;
 $ctf)
      map_prefix=CTF
	  ;;
 $dom)
      map_prefix=DOM
	  ;;
 $as)
      map_prefix=AS
	  ;;
 *)
      map_prefix=DM
	  ;;
esac

for backfile in ../Maps/$map_prefix-*.unr
	do
		# Since the map is now in the form ../Maps/<MAP_NAME.unr> we need to
		# strip off the ../Maps part.  I don't know how to do this in bash
		# so I'm just going to loop through the letters to get past the prefix
		line_string="$backfile \"\" \\"
		echo $line_string | sed 's/.*\/Maps\///' | sed 's/\.unr//' >> $UTSERVTMP/.map_menu_options
	done

read options_list < $UTSERVTMP/.map_menu_options
dialog $options_list 2> $UTSERVTMP/.temp_file_output

if [ $? != 0 ]; then
	die
fi

read choice < $UTSERVTMP/.temp_file_output

./generate_mutator_list.pl
read mutator_list < $UTSERVTMP/.mutators_available
dialog $mutator_list 2> $UTSERVTMP/.mutators_selected

if [ $? != 0 ]; then
	die
fi

# convert the list of mutators into a command line parameter
sed 's/" "/,/g' $UTSERVTMP/.mutators_selected | sed 's/"//g'  > $UTSERVTMP/.mutators_selected_string
read mutator_command_line < $UTSERVTMP/.mutators_selected_string

# If any mutators were selected then add them to the command line
mutator_choices=""
if [ "$mutator_command_line" != "" ]; then
	echo $mutator_command_line
	mutator_choices="?mutator=$mutator_command_line"
	echo $mutator_choices
fi

# scan sys dir for ini files
for initstring in *.ini
	do
		if [ "$initstring" != "User.ini" ]; then # this is not a UT server ini file
            #  I've commented this out because I felt
			#  it was confusing to see the messages
			#  printed to screen... AP
			# echo  "not User.ini" 
			echo  "$initstring \"\" \\" >> $UTSERVTMP/.init_string
		fi
	done

# add a default setting
echo "default \"\" \\" >> $UTSERVTMP/.init_string

read options_list < $UTSERVTMP/.init_string

dialog --menu "Server init file in System dir" 20 50 10 $options_list 2> $UTSERVTMP/.temp_file_output

read inifile < $UTSERVTMP/.temp_file_output

# doing the ini file thing
dot_ini_file=""

if [ "$inifile" = "default" ]; then
		echo "Using Default Init file"
elif [ "$inifile" = "" ]; then 
		echo "Using Default Init file"
else  
		echo "Using Init file $inifile"
		dot_ini_file="ini=$inifile"
fi

cleanup

# we're going to assume that the ucc wrapper script is in the PATH
# shouldn't call ucc-bin directly...
server_command_to_run="ucc server $choice$mutator_choices $dot_ini_file"

if [ "$choice" != "" ]; then
	echo $server_command_to_run
	$server_command_to_run
else
	die
fi
